@@ -58,11 +58,26 @@ extern char *hts_convertStringToUTF8(const char *s, size_t size,
 extern char *hts_convertStringFromUTF8(const char *s, size_t size,
                                        const char *charset);
 
+/**
+ * Convert an UTF-8 string to an IDNA (RFC 3492) string.
+ **/
+extern char *hts_convertStringUTF8ToIDNA(const char *s, size_t size);
+
 /**
  * Extract the charset from the HTML buffer "html"
  **/
 extern char *hts_getCharsetFromMeta(const char *html, size_t size);
 
+/**
+ * Is the given string an ASCII string ?
+ **/
+extern int hts_isStringAscii(const char *s, size_t size);
+
+/**
+ * Is the given charset the UTF-8 charset ?
+ **/
+extern int hts_isCharsetUTF8(const char *charset);
+
 /**
  * Get an UTF-8 string length in characters.
  **/
